/* @flow */
import React, { useEffect, useState } from 'react';
import isEqual from 'react-fast-compare';
import { FlatList, TouchableWithoutFeedback, View } from 'react-native';
const NodeView = React.memo(({ renderNode, extraData, level, getChildrenName, node, onNodePressed, }) => {
    // tslint:disable-next-line:variable-name
    const [_node, setNode] = useState(Object.assign({ opened: false }, node));
    useEffect(() => {
        setNode(Object.assign({}, node, { opened: _node.opened }));
    }, [node]);
    // tslint:disable-next-line:variable-name
    const _onNodePressed = () => {
        setNode(Object.assign({}, _node, { opened: !_node.opened }));
        if (onNodePressed) {
            onNodePressed(_node);
        }
    };
    // tslint:disable-next-line:variable-name
    const renderChildren = (item, _level) => {
        return (<NodeView getChildrenName={getChildrenName} node={item} level={_level + 1} extraData={extraData} onNodePressed={onNodePressed} renderNode={renderNode}/>);
    };
    const renderItem = ({ item }) => renderChildren(item, level);
    const rootChildrenName = getChildrenName(_node);
    const rootChildren = _node[rootChildrenName];
    return (<>
                {!_node.hidden ? (<TouchableWithoutFeedback onPress={_onNodePressed}>
                        <View>{renderNode(_node, level)}</View>
                    </TouchableWithoutFeedback>) : null}
                {_node.opened && rootChildren ? (<FlatList data={rootChildren} renderItem={renderItem} extraData={extraData} keyExtractor={(item) => item._internalId}/>) : null}
            </>);
}, isEqual);
export default NodeView;
//# sourceMappingURL=NodeView.js.map